==> eam-wshub-proxyclient-11.4-6-sources.jar: net/datastream/schemas/mp_fields/PMWORKPACKAGEEQUIPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour PMWORKPACKAGEEQUIPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="PMWORKPACKAGEEQUIPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMWORKPACKAGEEQUIPCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMREVISION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMWORKPACKAGEEQUIPID_Type", propOrder = {
    "pmworkpackageequipcode",
    "ppmrevision"
})
public class PMWORKPACKAGEEQUIPID_Type {

    @XmlElement(name = "PMWORKPACKAGEEQUIPCODE")
    protected long pmworkpackageequipcode;
    @XmlElement(name = "PPMREVISION")
    protected int ppmrevision;

    /**
     * Obtient la valeur de la propriété pmworkpackageequipcode.
     * 
     */
    public long getPMWORKPACKAGEEQUIPCODE() {
        return pmworkpackageequipcode;
    }

    /**
     * Définit la valeur de la propriété pmworkpackageequipcode.
     * 
     */
    public void setPMWORKPACKAGEEQUIPCODE(long value) {
        this.pmworkpackageequipcode = value;
    }

    /**
     * Obtient la valeur de la propriété ppmrevision.
     * 
     */
    public int getPPMREVISION() {
        return ppmrevision;
    }

    /**
     * Définit la valeur de la propriété ppmrevision.
     * 
     */
    public void setPPMREVISION(int value) {
        this.ppmrevision = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/PMWORKPACKAGEEQUIPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PMWORKPACKAGEEQUIPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PMWORKPACKAGEEQUIPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMWORKPACKAGEEQUIPCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PPMREVISION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PMWORKPACKAGEEQUIPID_Type", propOrder = {
    "pmworkpackageequipcode",
    "ppmrevision"
})
public class PMWORKPACKAGEEQUIPID_Type {

    @XmlElement(name = "PMWORKPACKAGEEQUIPCODE")
    protected long pmworkpackageequipcode;
    @XmlElement(name = "PPMREVISION")
    protected int ppmrevision;

    /**
     * Gets the value of the pmworkpackageequipcode property.
     * 
     */
    public long getPMWORKPACKAGEEQUIPCODE() {
        return pmworkpackageequipcode;
    }

    /**
     * Sets the value of the pmworkpackageequipcode property.
     * 
     */
    public void setPMWORKPACKAGEEQUIPCODE(long value) {
        this.pmworkpackageequipcode = value;
    }

    /**
     * Gets the value of the ppmrevision property.
     * 
     */
    public int getPPMREVISION() {
        return ppmrevision;
    }

    /**
     * Sets the value of the ppmrevision property.
     * 
     */
    public void setPPMREVISION(int value) {
        this.ppmrevision = value;
    }

}
